@@ -1,5 +1,6 @@
 {-# LANGUAGE CPP #-}
 {-# LANGUAGE DeriveDataTypeable         #-}
+{-# LANGUAGE DeriveGeneric #-}
 {-# LANGUAGE TupleSections #-}
 {-# LANGUAGE FlexibleInstances          #-}
 {-# LANGUAGE GeneralizedNewtypeDeriving #-}
@@ -41,6 +42,7 @@ import qualified Data.Text                          as T
 import qualified Data.Text.Lazy.Builder             as TBuilder
 import           Data.Time                          (UTCTime)
 import           Data.Typeable                      (Typeable)
+import           GHC.Generics                       (Generic)
 import           Language.Haskell.TH.Syntax         (Loc)
 import qualified Network.HTTP.Types                 as H
 import           Network.Wai                        (FilePart,
@@ -62,6 +64,7 @@ import           Control.Monad.Reader               (MonadReader (..))
 import Prelude hiding (catch)
 #endif
 import Control.DeepSeq (NFData (rnf))
+import Control.DeepSeq.Generics (genericRnf)
 import Data.Conduit.Lazy (MonadActive, monadActive)
 import Yesod.Core.TypeCache (TypeMap, KeyedTypeMap)
 #if MIN_VERSION_monad_logger(0, 3, 10)
@@ -314,7 +317,9 @@ data ErrorResponse =
     | NotAuthenticated
     | PermissionDenied Text
     | BadMethod H.Method
-    deriving (Show, Eq, Typeable)
+    deriving (Show, Eq, Typeable, Generic)
+instance NFData ErrorResponse where
+    rnf = genericRnf
 
 ----- header stuff
 -- | Headers to be added to a 'Result'.
