@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE TemplateHaskell #-}
 {-# LANGUAGE RecordWildCards #-}
 module Yesod.Routes.TH.RouteAttrs
@@ -13,7 +14,7 @@ import Data.Text (pack)
 mkRouteAttrsInstance :: Type -> [ResourceTree a] -> Q Dec
 mkRouteAttrsInstance typ ress = do
     clauses <- mapM (goTree id) ress
-    return $ InstanceD [] (ConT ''RouteAttrs `AppT` typ)
+    return $ instanceD [] (ConT ''RouteAttrs `AppT` typ)
         [ FunD 'routeAttrs $ concat clauses
         ]
 
@@ -36,3 +37,10 @@ goRes front Resource {..} =
         []
   where
     toText s = VarE 'pack `AppE` LitE (StringL s)
+
+instanceD :: Cxt -> Type -> [Dec] -> Dec
+#if MIN_VERSION_template_haskell(2,11,0)
+instanceD = InstanceD Nothing
+#else
+instanceD = InstanceD
+#endif
